Light Characteristics
=====================

You can make up your own, based on the information on
`Wikipedia <https://en.wikipedia.org/wiki/Light_characteristic>`_
or as described in the features.

Alternatively, you could look up some real examples from a light list.

The American `National Geospatial Intelligence Agency <https://msi.nga.mil/Publications/NGALOL>`_
is a good source.
